pub fn gizmo_rotation(
global_tf: &GlobalTransform,
space: &TransformGizmoSpace,
) -> QuatExpand description
Compute the gizmo rotation based on the space setting.
pub fn gizmo_rotation(
global_tf: &GlobalTransform,
space: &TransformGizmoSpace,
) -> QuatCompute the gizmo rotation based on the space setting.