translation_plane_normal

Function translation_plane_normal 

pub fn translation_plane_normal(ray: Ray3d, axis: Vec3) -> Vec3
Construct the constraint plane normal for axis translation/scale.

The plane contains the drag axis and is oriented to face the camera as much as possible, matching the approach from bevy_transform_gizmo.